//     Author: Maurizio Loreti, aka MLO or (HAM) I3NOO
//     Work:   University of Padova - Department of Physics
//             Via F. Marzolo, 8 - 35131 PADOVA - Italy
//     Phone:  +39 (049) 827-7216   FAX: +39 (049) 827-7102
//     EMail:  loreti@pd.infn.it
//     WWW:    http://www.pd.infn.it/~loreti/mlo.html
//
// -------------------------------------------------------------------
// $Id: client.cxx,v 1.2 2002/12/15 10:10:07 loreti Exp $
// -------------------------------------------------------------------
// Implementation of the methods and procedures defined in the header
// file "client.hh".
// -------------------------------------------------------------------

#include <stdexcept>
#include "client.hh"

using std::runtime_error;
using std::string;

// Static values and non-inline methods for the class "Client"

const Client::socket_type Client::INVALID = -1;

string Client::getServerName() const {
  // Gets the name of the connected host, if available

  static const size_t BUFLEN = 128;
  char                buffer[BUFLEN];

  if (sockFD_ < 0   ||
      inet_ntop(domain_, &servAddr_.sin_addr,
                buffer, BUFLEN) == 0) {
    return "";
  }
  return buffer;
}

void Client::setSocket(
  int type
) {
  // Currently, the only supported domain is AF_INET

  if (domain_ != AF_INET) {
    throw runtime_error("Domain not supported");
  }

  // The supplied host and port must be valid

  if (!address_.isValid()) {
    throw runtime_error("Invalid host");
  }

  if (!port_.isValid()) {
    throw runtime_error("Invalid port");
  }

  // Overall initialization of the connecting socket.  For the first
  // thing, we get a socket...

  sockFD_ = socket(domain_, type, 0);
  if (sockFD_ < 0) {
    string s( strerror(errno) );
    s = "(socket) " + s;
    throw runtime_error(s);
  }

  std::memset(&servAddr_, 0, sizeof(servAddr_));
  servAddr_.sin_family      = domain_;
  servAddr_.sin_addr.s_addr = address_.getNetAddr();
  servAddr_.sin_port        = port_.getNetValue();

  if (connect(sockFD_,
              reinterpret_cast<struct sockaddr *>(&servAddr_),
              sizeof(servAddr_)) < 0) {
    string s( strerror(errno) );
    s = "(connect) " + s;
    throw runtime_error(s);
  }
}
