//     Author: Maurizio Loreti, aka MLO or (HAM) I3NOO
//     Work:   University of Padova - Department of Physics
//             Via F. Marzolo, 8 - 35131 PADOVA - Italy
//     Phone:  +39 (049) 827-7216   FAX: +39 (049) 827-7102
//     EMail:  loreti@pd.infn.it
//     WWW:    http://www.pd.infn.it/~loreti/mlo.html
//
// -------------------------------------------------------------------
// $Id: ipcclient.cxx,v 1.1 2002/11/28 17:50:59 loreti Exp $
// -------------------------------------------------------------------
// A toy implementation of a client that connects to the server
// defined in "ipcserver.cxx" (see there for more explanations).
// -------------------------------------------------------------------

#include <iostream>
#include <stdexcept>
#include <cstdlib>
#include "client.hh"

using std::cerr;
using std::cout;
using std::endl;

int main(
  int    argc,
  char * argv[]
) {
  // Command line arguments

  if (argc != 3) {
    cerr << "Usage: " << argv[0] << " <host> <port>\n";
    return EXIT_SUCCESS;
  }

  try {
    // Initializes a connecting socket

    Client c(AF_INET, SOCK_STREAM, argv[1], atoi(argv[2]));
    cout << "Client: connected to server at " << c.getServerName()
         << ", port " << c.getHostServerPort() << endl;

    // Sends to the server the characters in the array "buffer"; then
    // closes the connection.

    static const char buffer[] = "Hello";
    const char *      pc;

    for (pc = buffer;   *pc  &&  c.isConnected();   ++pc) {
      char n;

      if (c.sockPut(pc) > 0   &&   c.sockGet(&n) > 0) {
        cout << "Client: sent " << *pc << ", got "
             << static_cast<int>(n) << endl;
      }
    }
  } catch (const std::exception & e) {
    cerr << "Exception - "  << e.what() << '\n';
  }
}
